@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2021 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2022 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -40,8 +40,9 @@ import bcrypt  # pip install bcrypt; see https://pypi.org/project/bcrypt/
 BCRYPT_DEFAULT_LOG_ROUNDS = 12  # bcrypt default; work factor is 2^this.
 
 
-def hash_password(plaintextpw: str,
-                  log_rounds: int = BCRYPT_DEFAULT_LOG_ROUNDS) -> str:
+def hash_password(
+    plaintextpw: str, log_rounds: int = BCRYPT_DEFAULT_LOG_ROUNDS
+) -> str:
     """
     Makes a hashed password (using a new salt) using ``bcrypt``.
 
