@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2021 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2022 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -42,6 +42,7 @@ from typing import Tuple, Union
 # Rounding/truncation
 # =============================================================================
 
+
 def round_half_up(x: Union[float, Decimal], dp: int = 0) -> Decimal:
     """
     Rounds, with halves going up (positive).
@@ -58,9 +59,9 @@ def round_half_up(x: Union[float, Decimal], dp: int = 0) -> Decimal:
     x = Decimal(x)
     context = decimal.getcontext()
     factor = context.power(10, dp)
-    y = (
-        x * factor + Decimal("0.5")
-    ).quantize(Decimal("1"), rounding=decimal.ROUND_FLOOR) / factor
+    y = (x * factor + Decimal("0.5")).quantize(
+        Decimal("1"), rounding=decimal.ROUND_FLOOR
+    ) / factor
     # print(f"round_half_up({x}, {dp}) = {y}")
     return y
 
@@ -86,6 +87,7 @@ def truncate(x: Union[float, Decimal], dp: int = 0) -> Decimal:
 # Reverse rounding/truncation
 # =============================================================================
 
+
 def remove_exponent_from_decimal(d: Decimal) -> Decimal:
     """
     Converts a decimal like ``5.0E+3`` to ``5000``.
@@ -117,10 +119,9 @@ def num_dp_from_decimal(x: Decimal, with_negative_dp: bool = False) -> int:
     return len(components[1])
 
 
-def range_roundable_up_to(y: Union[int, float, Decimal],
-                          dp: int = 0,
-                          with_description: bool = False) \
-        -> Union[Tuple[Decimal, Decimal], Tuple[Decimal, Decimal, str]]:
+def range_roundable_up_to(
+    y: Union[int, float, Decimal], dp: int = 0, with_description: bool = False
+) -> Union[Tuple[Decimal, Decimal], Tuple[Decimal, Decimal, str]]:
     """
     Suppose some value ``x`` was rounded to ``y`` with ``dp`` decimal places,
     using the "round half up" rounding method (see implementation in
@@ -150,7 +151,6 @@ def range_roundable_up_to(y: Union[int, float, Decimal],
     half = Decimal("0.5") * decimal.getcontext().power(10, -dp)
     a = y - half
     b = y + half
-    # print(f"range_roundable_up_to(y={y}, dp={dp}): half={half}, a={a}, b={b}")  # noqa
     if with_description:
         description = f"[{a}, {b})"
         return a, b, description
@@ -158,10 +158,9 @@ def range_roundable_up_to(y: Union[int, float, Decimal],
         return a, b
 
 
-def range_truncatable_to(y: Union[int, float, Decimal],
-                         dp: int = 0,
-                         with_description: bool = False) \
-        -> Union[Tuple[Decimal, Decimal], Tuple[Decimal, Decimal, str]]:
+def range_truncatable_to(
+    y: Union[int, float, Decimal], dp: int = 0, with_description: bool = False
+) -> Union[Tuple[Decimal, Decimal], Tuple[Decimal, Decimal, str]]:
     """
     Some value ``x`` was truncated to ``y`` with ``dp`` decimal places, as per
     the implementation in :func:`truncate`. Return the range within which ``x``
