@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2021 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2022 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -45,11 +45,13 @@ from cardinal_pythonlib.sqlalchemy.dialect import SqlaDialectName
 # ArrowType that uses fractional second support in MySQL
 # =============================================================================
 
+
 class ArrowMicrosecondType(TypeDecorator):
     """
     Based on ArrowType from SQLAlchemy-Utils, but copes with fractional seconds
     under MySQL 5.6.4+.
     """
+
     impl = DateTime
     # RNC: For MySQL, need to use sqlalchemy.dialects.mysql.DATETIME(fsp=6);
     # see load_dialect_impl() below.
@@ -57,33 +59,38 @@ class ArrowMicrosecondType(TypeDecorator):
     def __init__(self, *args, **kwargs) -> None:
         if not arrow:
             raise AssertionError(
-                "'arrow' package is required to use 'ArrowMicrosecondType'")
+                "'arrow' package is required to use 'ArrowMicrosecondType'"
+            )
         super().__init__(*args, **kwargs)
 
     def load_dialect_impl(self, dialect: DefaultDialect) -> TypeEngine:  # RNC
         if dialect.name == SqlaDialectName.MYSQL:
             return dialect.type_descriptor(
-                sqlalchemy.dialects.mysql.DATETIME(fsp=6))
+                sqlalchemy.dialects.mysql.DATETIME(fsp=6)
+            )
         elif dialect.name == SqlaDialectName.MSSQL:  # Microsoft SQL Server
             return dialect.type_descriptor(sqlalchemy.dialects.mssql.DATETIME2)
         else:
             return dialect.type_descriptor(self.impl)
 
     def process_bind_param(
-            self, value: Any,
-            dialect: DefaultDialect) -> Optional[datetime.datetime]:
+        self, value: Any, dialect: DefaultDialect
+    ) -> Optional[datetime.datetime]:
         if value:
-            return self._coerce(value).to('UTC').naive
+            return self._coerce(value).to("UTC").naive
             # RNC: unfortunately... can't store and retrieve timezone, see docs
         return value
 
-    def process_result_value(self, value: Any,
-                             dialect: DefaultDialect) -> Optional[arrow.Arrow]:
+    def process_result_value(
+        self, value: Any, dialect: DefaultDialect
+    ) -> Optional[arrow.Arrow]:
         if value:
             return arrow.get(value)
         return value
 
-    def process_literal_param(self, value: Any, dialect: DefaultDialect) -> str:
+    def process_literal_param(
+        self, value: Any, dialect: DefaultDialect
+    ) -> str:
         return str(value)
 
     # noinspection PyMethodMayBeStatic
@@ -99,8 +106,9 @@ class ArrowMicrosecondType(TypeDecorator):
         return value
 
     # noinspection PyUnusedLocal
-    def coercion_listener(self, target, value, oldvalue,
-                          initiator) -> Optional[arrow.Arrow]:
+    def coercion_listener(
+        self, target, value, oldvalue, initiator
+    ) -> Optional[arrow.Arrow]:
         return self._coerce(value)
 
     @property
